<?php
/**
 * @category  Pinpoint
 * @package   Pinpoint_Faq
 * @copyright Copyright (c) 2019 Pinpoint Designs. (http://www.Pinpoint.co.uk)
 * @author    Ahmed Goda <hello@Pinpoint.co.uk>
 */

namespace Pinpoint\Faq\Setup;

use Magento\Framework\DB\Ddl\Table;
use Magento\Framework\Setup\InstallSchemaInterface;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\SchemaSetupInterface;
use Pinpoint\Faq\Api\Data\FaqInterface;

/**
 * Class InstallSchema
 */
class InstallSchema implements InstallSchemaInterface
{
    /**
     * Installs DB schema for a module
     *
     * @param SchemaSetupInterface $setup
     * @param ModuleContextInterface $context
     * @return void
     * @throws \Zend_Db_Exception
     */
    public function install(SchemaSetupInterface $setup, ModuleContextInterface $context)
    {
        $setup->startSetup();

        $table = $setup->getConnection()->newTable(
            $setup->getTable(FaqInterface::TABLE_NAME)
        )->addColumn(
            FaqInterface::FAQ_ID,
            Table::TYPE_INTEGER,
            null,
            [
                'identity' => true,
                'nullable' => false,
                'primary' => true,
                'unsigned' => true,
            ]
        )->addColumn(
            FaqInterface::CUSTOMER_NAME,
            Table::TYPE_TEXT,
            255,
            [
                'nullable' => false,
            ]
        )->addColumn(
            FaqInterface::CUSTOMER_EMAIL,
            Table::TYPE_TEXT,
            320,
            [
                'nullable' => false,
            ]
        )->addColumn(
            FaqInterface::QUESTION_TEXT,
            Table::TYPE_TEXT,
            255,
            [
                'nullable' => false,
            ]
        )->addColumn(
            FaqInterface::ANSWER_TEXT,
            Table::TYPE_TEXT,
            500,
            [
                'nullable' => false,
            ]
        )->addColumn(
            FaqInterface::IS_ACTIVE,
            Table::TYPE_BOOLEAN,
            null,
            [
                'nullable' => false,
                'default' => false
            ]
        )->addColumn(
            FaqInterface::IS_CUSTOMER_NOTIFIED,
            Table::TYPE_BOOLEAN,
            null,
            [
                'nullable' => false,
                'default' => false
            ]
        )->addColumn(
            FaqInterface::PRODUCT_ID,
            Table::TYPE_INTEGER,
            null,
            [
                'nullable' => false,
                'unsigned' => true,
            ]
        )->addColumn(
            FaqInterface::CREATED_AT,
            Table::TYPE_TIMESTAMP,
            null,
            [
                'nullable' => false,
                'default' => Table::TIMESTAMP_INIT,
            ]
        )->addColumn(
            FaqInterface::UPDATED_AT,
            Table::TYPE_TIMESTAMP,
            null,
            [
                'nullable' => false,
                'default' => Table::TIMESTAMP_INIT_UPDATE
            ]
        );

        $setup->getConnection()->createTable($table);

        $setup->endSetup();
    }
}
